*$ CREATE WVLNSH.FOR
*COPY WVLNSH
*
*=== Wvlnsh ===========================================================*
*
      SUBROUTINE WVLNSH ( EKPHOT, WVLNGT, MREG  , MMAT  , NWVSHP,
     &                    WVSHPH, DWVSHP, MXWSPH )

      INCLUDE '(DBLPRC)'
      INCLUDE '(DIMPAR)'
      INCLUDE '(IOUNIT)'
*
*----------------------------------------------------------------------*
*                                                                      *
*     Copyright (C) 1997-2010      by    Alfredo Ferrari & Paola Sala  *
*     All Rights Reserved.                                             *
*                                                                      *
*                                                                      *
*     WaVe LeNgth SHifted photon production:                           *
*                                                                      *
*     Created on 21 september 1997 by    Alfredo Ferrari & Paola Sala  *
*                                                   Infn - Milan       *
*                                                                      *
*     Last change on 16-Dec-10     by    Alfredo Ferrari               *
*                                                                      *
*    Note the wavelength is always assumed to be the vacuum one        *
*                                                                      *
*    Input variables:                                                  *
*                                                                      *
*          Ekphot = absorbed photon energy     (GeV)                   *
*          Wvlngt = absorbed photon wave-length (cm)                   *
*          Mreg   = current region                                     *
*          Mmat   = current material                                   *
*          Mxwsph = maximum number of secondary photons                *
*                                                                      *
*                                                                      *
*    Output variables:                                                 *
*                                                                      *
*          Nwvshp = number of produced secondary photons               *
*       Wvshph(i) > 0 -> energy    (GeV) of the i_th produced photon   *
*                 < 0 -> wavelength (cm) of the i_th produced photon   *
*       Dwvshp(i) = production delay (s) of the i_th produced photon   *
*                                                                      *
*----------------------------------------------------------------------*
*
      DIMENSION WVSHPH (MXWSPH), DWVSHP (MXWSPH)
*
      NWVSHP = 0
      RETURN
*=== End of subroutine Wvlnsh =========================================*
      END

